@@ -618,12 +618,12 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	SpinBox11 = new QSpinBox( GroupBox11, "SpinBox1" );
 	SpinBox11->setMinValue(1);
 	SpinBox11->setMaxValue(item->annotation().ActionType() == 7 ? 1000 : Seite);
-	SpinBox11->setValue(item->annotation().Ziel()+1);
+	SpinBox11->setValue(QMIN(item->annotation().Ziel()+1, Seite));
 	GroupBox11Layout->addWidget( SpinBox11, 1, 1 );
 	if (item->annotation().ActionType() == 7)
 		Pg1 = new Navigator( GroupBox11, 100, item->annotation().Ziel()+1, view, item->annotation().Extern());
 	else
-		Pg1 = new Navigator( GroupBox11, 100, item->annotation().Ziel(), view);
+		Pg1 = new Navigator( GroupBox11, 100, QMIN(item->annotation().Ziel(), Seite-1), view);
 	Pg1->setMinimumSize(QSize(Pg1->pmx.width(), Pg1->pmx.height()));
 	GroupBox11Layout->addMultiCellWidget(Pg1, 1, 3, 2, 2);
 	TextLabel41 = new QLabel( GroupBox11, "TextLabel4" );
@@ -1665,8 +1665,8 @@ void Annot::SetPg(int v)
 	}
 	else
 	{
-		Pg1->SetSeite(v-1, 100);
-		SpinBox11->setValue(v);
+		Pg1->SetSeite(QMIN(v-1, MaxSeite-1), 100);
+		SpinBox11->setValue(QMIN(v, MaxSeite));
 		Breite = OriBreite;
 		Hoehe = OriHoehe;
 		//		SetCo(0,0);
