@@ -210,7 +210,7 @@ int	ColorFancyPixmapItem::width( const QListBox *lb )  const
 ColorListBox::ColorListBox(QWidget * parent, const char * name, WFlags f)
 	: QListBox(parent, name, f)
 {
-	if (name == "")
+	if (!name || strlen(name) == 0)
 		setName("ColorListBox");
 }
 
@@ -588,127 +588,7 @@ void ColorManager::loadFarben()
 
 void ColorManager::delUnused()
 {
-	PageItem* ite;
-	bool found;
-	UsedC.clear();
-	ColorList::Iterator it;
-	for (it = EditColors.begin(); it != EditColors.end(); ++it)
-	{
-		found = false;
-		if ((it.key() == ScMW->doc->toolSettings.dBrush) || (it.key() == ScMW->doc->toolSettings.dPen) ||
-		        (it.key() == ScMW->doc->toolSettings.dBrushPict)
-		        || (it.key() == ScMW->doc->toolSettings.dPenLine) || (it.key() == ScMW->doc->toolSettings.dPenText))
-		{
-			UsedC.insert(it.key(), it.data());
-			continue;
-		}
-		for (uint c = 0; c < ScMW->doc->MasterItems.count(); ++c)
-		{
-			ite = ScMW->doc->MasterItems.at(c);
-			QPtrVector<VColorStop> cstops = ite->fill_gradient.colorStops();
-			for (uint cst = 0; cst < ite->fill_gradient.Stops(); ++cst)
-			{
-				if (it.key() == cstops.at(cst)->name)
-					found = true;
-				if (found)
-					break;
-			}
-			if ((ite->asTextFrame()) || (ite->asPathText()))
-			{
-				for (uint d=0; d<ite->itemText.count(); ++d)
-				{
-					if (it.key() == ite->itemText.at(d)->ccolor)
-						found = true;
-					if (it.key() == ite->itemText.at(d)->cstroke)
-						found = true;
-					if (found)
-						break;
-				}
-			}
-			/* PFJ - 29.02.04 - merged if's to one line */
-			if ((it.key() == ite->fillColor()) || (it.key() == ite->lineColor()))
-				found = true;
-			if (found)
-				break;
-		}
-		if (found)
-		{
-			UsedC.insert(it.key(), it.data());
-			continue;
-		}
-		for (uint c = 0; c < ScMW->doc->FrameItems.count(); ++c)
-		{
-			ite = ScMW->doc->FrameItems.at(c);
-			QPtrVector<VColorStop> cstops = ite->fill_gradient.colorStops();
-			for (uint cst = 0; cst < ite->fill_gradient.Stops(); ++cst)
-			{
-				if (it.key() == cstops.at(cst)->name)
-					found = true;
-				if (found)
-					break;
-			}
-			if ((ite->asTextFrame()) || (ite->asPathText()))
-			{
-				for (uint d=0; d<ite->itemText.count(); ++d)
-				{
-					if (it.key() == ite->itemText.at(d)->ccolor)
-						found = true;
-					if (it.key() == ite->itemText.at(d)->cstroke)
-						found = true;
-					if (found)
-						break;
-				}
-			}
-			/* PFJ - 29.02.04 - merged if's to one line */
-			if ((it.key() == ite->fillColor()) || (it.key() == ite->lineColor()))
-				found = true;
-			if (found)
-				break;
-		}
-		if (found)
-		{
-			UsedC.insert(it.key(), it.data());
-			continue;
-		}
-		for (uint c = 0; c < ScMW->doc->DocItems.count(); ++c)
-		{
-			ite = ScMW->doc->DocItems.at(c);
-			QPtrVector<VColorStop> cstops = ite->fill_gradient.colorStops();
-			for (uint cst = 0; cst < ite->fill_gradient.Stops(); ++cst)
-			{
-				if (it.key() == cstops.at(cst)->name)
-					found = true;
-				if (found)
-					break;
-			}
-			if ((ite->asTextFrame()) || (ite->asPathText()))
-			{
-				for (uint d=0; d<ite->itemText.count(); ++d)
-				{
-					/* PFJ - 29.02.04 - Merged if's */
-					if ((it.key() == ite->itemText.at(d)->ccolor) ||
-							(it.key() == ite->itemText.at(d)->cstroke))
-						found = true;
-					if (found)
-						break;
-				}
-			}
-			/* PFJ - 29.02.04 - Merged if's */
-			if ((it.key() == ite->fillColor()) || (it.key() == ite->lineColor()))
-				found = true;
-			if (found)
-				break;
-		}
-		/* PFJ - 29.02.04 - Merged if's */
-		if ((it.key() == ScMW->doc->CurrTextFill) ||
-		        (it.key() == ScMW->doc->CurrTextStroke))
-			found = true;
-		if (found)
-		{
-			UsedC.insert(it.key(), it.data());
-			continue;
-		}
-	}
+	ScMW->doc->getUsedColors(UsedC);
 	EditColors = UsedC;
 	EditColors.insert("White", ScColor(0, 0, 0, 0));
 	EditColors.insert("Black", ScColor(0, 0, 0, 255));
