@@ -89,7 +89,7 @@ public:
 	QString ImageToGray();
 	QString ImageToCMYK_PS(int pl, bool pre);
 	QString ImageToCMYK_PDF(bool pre);
-	QString getAlpha(QString fn, bool PDF, bool pdf14, int gsRes = 72);
+	QString getAlpha(QString fn, bool PDF, bool pdf14, int gsRes = 72, int scaleXSize = 0, int scaleYSize = 0);
 	void Convert2JPG(QString fn, int Quality, bool isCMYK, bool isGray);
 
 	// Image effects
